// require (PrototypeDate.js), 使用了format
import React, { forwardRef, useRef, useImperativeHandle, useEffect } from 'react';
import Instance from './instance.js';
var Calendar = forwardRef(function (_ref, ref) {
  var _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'month' : _ref$type,
      value = _ref.value,
      titleFormat = _ref.titleFormat,
      min = _ref.min,
      max = _ref.max,
      verticalDrag = _ref.verticalDrag,
      _ref$prevHTML = _ref.prevHTML,
      prevHTML = _ref$prevHTML === void 0 ? '&lt' : _ref$prevHTML,
      _ref$nextHTML = _ref.nextHTML,
      nextHTML = _ref$nextHTML === void 0 ? '&gt' : _ref$nextHTML,
      onChange = _ref.onChange,
      onClick = _ref.onClick,
      onError = _ref.onError;
  var rootRef = useRef(null);
  var instance = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      },
      getInstance: function getInstance() {
        return instance.current;
      },
      showWeek: function showWeek() {
        instance.current.showWeek();
      },
      showMonth: function showMonth() {
        instance.current.showMonth();
      },
      jumpTo: function jumpTo(jumpDate) {
        if (!instance.current) return;

        if (jumpDate instanceof Date) {
          instance.current.setDate(jumpDate);
        } else if (jumpDate === 'today') {
          instance.current.setToday();
        } else if (jumpDate === 'default') {
          instance.current.setDefaultDate();
        }
      }
    };
  });
  useEffect(function () {
    if (instance.current) return;
    initInstance();
  }, []); // eslint-disable-line
  // 更新句柄, 防止synchronization模式, 每次组件在render的时候都生成上次render的state、function、effects

  if (instance.current) {
    instance.current.params.onChange = handleChange;
    instance.current.params.onClick = handleClick;
    instance.current.params.onError = handleError;
  }

  function initInstance() {
    instance.current = new Instance(rootRef.current, {
      viewType: type,
      titleFormat: titleFormat,
      disableBeforeDate: min,
      disableAfterDate: max,
      verticalDrag: verticalDrag,
      defaultDate: value,
      prevHTML: prevHTML,
      nextHTML: nextHTML,
      onClick: handleClick,
      onChange: handleChange,
      onError: handleError // func(e, err)

    });
  }

  function handleClick(s) {
    if (onClick) onClick(s);
  }

  function handleChange(s) {
    // 如果选中日期和之前的相同则不需要触发onChange
    if (value && s.activeDate && JSON.stringify(value) === JSON.stringify(s.activeDate)) {
      return;
    }

    if (onChange) onChange(s.activeDate);
  }

  function handleError(s, err) {
    s.errMsg = err.errMsg;
    if (onError) onError(s);
  }

  return /*#__PURE__*/React.createElement("div", {
    ref: rootRef,
    className: "calendar"
  });
});
export default Calendar;