var _excluded = ["ak", "value", "onChange"];

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useRef, useEffect, useState } from 'react';
import MapUtil from './../../../MapUtil';
import Page from './../../../Page';
import Container from './../../../Container';
import Footer from './../../../Footer';
import Notice from './../../../Notice';
import locale from './../../../locale';
import Instance from './instance';
import Control from './Control';
var center = '江苏省,南京市';

function MapView(_ref) {
  var _value, _value2;

  var ak = _ref.ak,
      _ref$value = _ref.value,
      argValue = _ref$value === void 0 ? null : _ref$value,
      onChange = _ref.onChange,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var mapRef = useRef(null);
  var instance = useRef(null);

  var _useState = useState(argValue),
      value = _useState[0],
      setValue = _useState[1];

  var _useState2 = useState(true),
      loading = _useState2[0],
      setLoading = _useState2[1];

  var _useState3 = useState(false),
      errMsg = _useState3[0],
      setErrMsg = _useState3[1];

  useEffect(function () {
    setValue(argValue);
  }, [JSON.stringify(argValue)]); // eslint-disable-line

  useEffect(function () {
    if (!window.BMap && !ak) {
      setErrMsg(locale('请传入百度地图ak', 'hint_map_ak'));
      return;
    }

    MapUtil.load({
      ak: ak,
      success: function success() {
        initData();
      },
      fail: function fail() {
        setErrMsg(locale('地图库加载失败, 请稍后再试', 'hint_map_failed_load'));
      }
    }); // 移除组件时注销

    return function () {
      if (instance.current) {
        instance.current.destroy();
      }
    };
  }, []); // eslint-disable-line
  // 绘制标记点

  useEffect(function () {
    handleMarker();
  }, [loading]); // eslint-disable-line
  // 初始化地图

  function initData() {
    if (!window.BMap) {
      // 如果有高德地图, 则加上 || !window.AMap
      setErrMsg(locale('地图库加载失败, 请稍后再试', 'hint_map_failed_load'));
      return;
    }

    console.log('初始化地图' + center);

    if (!mapRef.current) {
      setErrMsg(locale('地图容器不存在', 'hint_map_no_container'));
      return;
    }

    var temp = new Instance();
    temp.initMap(mapRef.current, center, function (result) {
      if (typeof result === 'string') {
        setErrMsg(result);
        return;
      }

      instance.current = temp; // 拖拽选点

      instance.current.initDragPoint(function (newValue) {
        if (newValue) {
          setValue(newValue);
        } else {
          handleReset();
        }
      });
      setErrMsg('');
      setLoading(false);
    });
  } // 绘制标记点


  function handleMarker() {
    if (instance.current && value && value.latitude && value.longitude) {
      var point = [value.longitude, value.latitude];
      instance.current.drawMarker(point);
      setTimeout(function () {
        handleReset();
      }, 200);
    }
  } // 还原位置


  function handleReset() {
    if (value && value.longitude && value.latitude) {
      instance.current.centerToPoint([value.longitude, value.latitude]);
    }
  } // 修改位置


  function handleLocation(newValue) {
    value = newValue;
    setValue(newValue); // 绘制标记点

    handleMarker();
  } // 点击确定


  function handleSubmit() {
    if (onChange) onChange(value);
  }

  return /*#__PURE__*/React.createElement(Page, props, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement("div", {
    ref: mapRef,
    className: "map-container"
  }), /*#__PURE__*/React.createElement(Control.Location, {
    instance: instance,
    value: value,
    onChange: handleLocation
  })), /*#__PURE__*/React.createElement(Footer, {
    className: "map-footer"
  }, /*#__PURE__*/React.createElement("div", {
    className: "map-footer-content",
    onClick: handleReset
  }, /*#__PURE__*/React.createElement("p", {
    className: "map-footer-content-caption"
  }, locale('当前位置', 'current_location')), /*#__PURE__*/React.createElement("p", {
    className: "map-footer-content-sndcaption"
  }, ((_value = value) === null || _value === void 0 ? void 0 : _value.value) || '')), ((_value2 = value) === null || _value2 === void 0 ? void 0 : _value2.value) && /*#__PURE__*/React.createElement("span", {
    className: "map-footer-submit",
    onClick: handleSubmit
  }, locale('确定', 'ok'))), errMsg && /*#__PURE__*/React.createElement(Notice, {
    caption: errMsg
  }));
}

export default MapView;