var _excluded = ["ak", "value"];

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useRef, useEffect, useState } from 'react';
import MapUtil from './../../../MapUtil';
import Page from './../../../Page';
import Container from './../../../Container';
import Footer from './../../../Footer';
import Notice from './../../../Notice';
import locale from './../../../locale';
import Instance from './instance';
var center = '江苏省,南京市';

function MapView(_ref) {
  var ak = _ref.ak,
      value = _ref.value,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var mapRef = useRef(null);
  var instance = useRef(null);

  var _useState = useState(true),
      loading = _useState[0],
      setLoading = _useState[1];

  var _useState2 = useState(false),
      errMsg = _useState2[0],
      setErrMsg = _useState2[1];

  useEffect(function () {
    if (!window.BMap && !ak) {
      setErrMsg(locale('请传入百度地图ak', 'hint_map_ak'));
      return;
    }

    MapUtil.load({
      ak: ak,
      success: function success() {
        initData();
      },
      fail: function fail() {
        setErrMsg(locale('地图库加载失败, 请稍后再试', 'hint_map_failed_load'));
      }
    }); // 移除组件时注销

    return function () {
      if (instance.current) {
        instance.current.destroy();
      }
    };
  }, []); // eslint-disable-line
  // 绘制标记点

  useEffect(function () {
    if (loading) return;

    if (instance.current && value && value.latitude && value.longitude) {
      var point = [value.longitude, value.latitude];
      instance.current.drawMarker(point);
      setTimeout(function () {
        handleReset();
      }, 200);
    }
  }, [loading]); // eslint-disable-line
  // 初始化地图

  function initData() {
    if (!window.BMap) {
      // 如果有高德地图, 则加上 || !window.AMap
      setErrMsg(locale('地图库加载失败, 请稍后再试', 'hint_map_failed_load'));
      return;
    }

    console.log('初始化地图' + center);

    if (!mapRef.current) {
      setErrMsg(locale('地图容器不存在', 'hint_map_no_container'));
      return;
    }

    var temp = new Instance();
    temp.initMap(mapRef.current, center, function (result) {
      if (typeof result === 'string') {
        setErrMsg(result);
        return;
      }

      instance.current = temp;
      setErrMsg('');
      console.log(loading);
      setLoading(false);
    });
  } // 还原位置


  function handleReset() {
    if (value && value.longitude && value.latitude) {
      instance.current.centerToPoint([value.longitude, value.latitude]);
    }
  }

  return /*#__PURE__*/React.createElement(Page, props, /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement("div", {
    ref: mapRef,
    className: "map-container"
  })), /*#__PURE__*/React.createElement(Footer, {
    className: "map-footer"
  }, /*#__PURE__*/React.createElement("div", {
    className: "map-footer-content",
    onClick: handleReset
  }, /*#__PURE__*/React.createElement("p", {
    className: "map-footer-content-caption"
  }, locale('当前位置', 'current_location')), /*#__PURE__*/React.createElement("p", {
    className: "map-footer-content-sndcaption"
  }, (value === null || value === void 0 ? void 0 : value.value) || ''))), errMsg && /*#__PURE__*/React.createElement(Notice, {
    caption: errMsg
  }));
}

export default MapView;