var _excluded = ["ak", "show", "portal", "title", "prevTitle", "onHide", "center", "points", "circle", "polygon", "district", "header", "children"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useRef, useContext, useEffect, useState } from 'react';
import { createPortal } from 'react-dom';
import MapUtil from './../MapUtil';
import Page from './../Page';
import Header from './../Header';
import Container from './../Container';
import Notice from './../Notice';
import Bridge from './../Bridge';
import Wrapper from './Wrapper';
import Close from './Close';
import MapInstance from './MapInstance';
import Context from './../Context/instance.js';

function MapView(_ref) {
  var ak = _ref.ak,
      _ref$show = _ref.show,
      show = _ref$show === void 0 ? true : _ref$show,
      portal = _ref.portal,
      title = _ref.title,
      prevTitle = _ref.prevTitle,
      onHide = _ref.onHide,
      _ref$center = _ref.center,
      center = _ref$center === void 0 ? '江苏省,南京市' : _ref$center,
      points = _ref.points,
      circle = _ref.circle,
      polygon = _ref.polygon,
      district = _ref.district,
      header = _ref.header,
      children = _ref.children,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var _useState = useState(null),
      mapInstance = _useState[0],
      setMapInstance = _useState[1]; // context


  var context = useContext(Context) || {};

  var locale = context.locale || function (remark) {
    return remark || '';
  };

  var refWrapperEl = useRef(null);

  var _useState2 = useState(''),
      errMsg = _useState2[0],
      setErrMsg = _useState2[1];

  useEffect(function () {
    if (!window.BMap && !ak) {
      setErrMsg(locale('请传入百度地图ak', 'hint_map_ak'));
      return;
    }

    MapUtil.load({
      ak: ak,
      success: function success() {
        initData();
      },
      fail: function fail() {
        setErrMsg(locale('地图库加载失败, 请稍后再试', 'hint_map_failed_load'));
      }
    }); // 移除组件时注销

    return function () {
      // 设置上一页标题
      handleTitle(prevTitle); // 移除实例化对象

      mapInstance.destroy();
    };
  }, []); // eslint-disable-line
  // 隐藏时, 移除标注
  // useEffect(() => {
  //   if (show === false) {
  //     mapInstance.destroy();
  //   }
  // }, [show])
  // 初始化地图

  function initData() {
    if (!window.BMap) {
      // 如果有高德地图, 则加上 || !window.AMap
      setErrMsg(locale('地图库加载失败, 请稍后再试', 'hint_map_failed_load'));
      return;
    }

    console.log('初始化地图' + center);

    if (!refWrapperEl.current) {
      setErrMsg(locale('地图容器不存在', 'hint_map_no_container'));
      return;
    }

    mapInstance = new MapInstance();
    setMapInstance(mapInstance);
    mapInstance.initMap(refWrapperEl.current, center, function (result) {
      if (typeof result === 'string') {
        setErrMsg(result);
        return;
      }
    });
  } // 绘制标记点


  useEffect(function () {
    if (points && points.length && show && mapInstance) {
      console.log('绘制标记');
      console.log(mapInstance);
      mapInstance.drawMarkers(points);
    }
  }, [points]); // eslint-disable-line
  // 绘制圆形

  useEffect(function () {
    if (circle && circle.point && show) {
      console.log('绘制圆形');
      mapInstance.drawCircle(circle.point, circle.radius);
    }
  }, [circle]); // eslint-disable-line
  // 绘制多边形

  useEffect(function () {
    if (polygon && show) {
      console.log('绘制多边形');
      mapInstance.drawPolygon(polygon);
    }
  }, [polygon]); // eslint-disable-line
  // 绘制地区

  useEffect(function () {
    if (district && show) {
      console.log('绘制区域');
      var districtName = [];

      for (var name in district) {
        districtName.push(district[name].name);
      }

      mapInstance.drawDistrict(districtName.join(','));
    }
  }, [district]); // eslint-disable-line
  // 显隐

  useEffect(function () {
    if (show) {
      handleTitle(title);
    } else {
      handleTitle(prevTitle);
    }
  }, [show]); // 中断绘制

  useEffect(function () {
    if (show) {
      if (errMsg) {
        mapInstance.abort = true;
      } else {
        mapInstance.abort = false;
      }
    }
  }, [errMsg]); // 设置标题

  function handleTitle(title) {
    if (!title) return;

    if (typeof title === 'string') {
      Bridge.setTitle({
        title: title
      });
    } else if (typeof title === 'function') {
      title();
    }
  }

  var DOM = /*#__PURE__*/React.createElement(Page, _extends({}, others, {
    className: (show ? '' : 'hide') + ((others === null || others === void 0 ? void 0 : others.className) ? ' ' + others.className : '')
  }), header && /*#__PURE__*/React.createElement(Header, null, header), /*#__PURE__*/React.createElement(Container, null, /*#__PURE__*/React.createElement(Wrapper, {
    ref: refWrapperEl
  }), onHide && /*#__PURE__*/React.createElement(Close, {
    onClick: onHide
  }), children), errMsg && /*#__PURE__*/React.createElement(Notice, {
    caption: errMsg
  }));

  if (portal) {
    return createPortal(DOM, portal);
  }

  return DOM;
}

export default MapView;