"use strict";

exports.__esModule = true;
exports["default"] = void 0;

var _react = _interopRequireWildcard(require("react"));

var _MapUtil = _interopRequireDefault(require("./../../../MapUtil"));

var _Page = _interopRequireDefault(require("./../../../Page"));

var _Container = _interopRequireDefault(require("./../../../Container"));

var _Footer = _interopRequireDefault(require("./../../../Footer"));

var _Notice = _interopRequireDefault(require("./../../../Notice"));

var _locale = _interopRequireDefault(require("./../../../locale"));

var _instance = _interopRequireDefault(require("./instance"));

var _Control = _interopRequireDefault(require("./Control"));

var _excluded = ["ak", "value", "onChange"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var center = '江苏省,南京市';

function MapView(_ref) {
  var _value, _value2;

  var ak = _ref.ak,
      _ref$value = _ref.value,
      argValue = _ref$value === void 0 ? null : _ref$value,
      onChange = _ref.onChange,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  var mapRef = (0, _react.useRef)(null);
  var instance = (0, _react.useRef)(null);

  var _useState = (0, _react.useState)(argValue),
      value = _useState[0],
      setValue = _useState[1];

  var _useState2 = (0, _react.useState)(true),
      loading = _useState2[0],
      setLoading = _useState2[1];

  var _useState3 = (0, _react.useState)(false),
      errMsg = _useState3[0],
      setErrMsg = _useState3[1];

  (0, _react.useEffect)(function () {
    setValue(argValue);
  }, [JSON.stringify(argValue)]); // eslint-disable-line

  (0, _react.useEffect)(function () {
    if (!window.BMap && !ak) {
      setErrMsg((0, _locale["default"])('请传入百度地图ak', 'hint_map_ak'));
      return;
    }

    _MapUtil["default"].load({
      ak: ak,
      success: function success() {
        initData();
      },
      fail: function fail() {
        setErrMsg((0, _locale["default"])('地图库加载失败, 请稍后再试', 'hint_map_failed_load'));
      }
    }); // 移除组件时注销


    return function () {
      if (instance.current) {
        instance.current.destroy();
      }
    };
  }, []); // eslint-disable-line
  // 绘制标记点

  (0, _react.useEffect)(function () {
    handleMarker();
  }, [loading]); // eslint-disable-line
  // 初始化地图

  function initData() {
    if (!window.BMap) {
      // 如果有高德地图, 则加上 || !window.AMap
      setErrMsg((0, _locale["default"])('地图库加载失败, 请稍后再试', 'hint_map_failed_load'));
      return;
    }

    console.log('初始化地图' + center);

    if (!mapRef.current) {
      setErrMsg((0, _locale["default"])('地图容器不存在', 'hint_map_no_container'));
      return;
    }

    var temp = new _instance["default"]();
    temp.initMap(mapRef.current, center, function (result) {
      if (typeof result === 'string') {
        setErrMsg(result);
        return;
      }

      instance.current = temp; // 拖拽选点

      instance.current.initDragPoint(function (newValue) {
        if (newValue) {
          setValue(newValue);
        } else {
          handleReset();
        }
      });
      setErrMsg('');
      setLoading(false);
    });
  } // 绘制标记点


  function handleMarker() {
    if (instance.current && value && value.latitude && value.longitude) {
      var point = [value.longitude, value.latitude];
      instance.current.drawMarker(point);
      setTimeout(function () {
        handleReset();
      }, 200);
    }
  } // 还原位置


  function handleReset() {
    if (value && value.longitude && value.latitude) {
      instance.current.centerToPoint([value.longitude, value.latitude]);
    }
  } // 修改位置


  function handleLocation(newValue) {
    value = newValue;
    setValue(newValue); // 绘制标记点

    handleMarker();
  } // 点击确定


  function handleSubmit() {
    if (onChange) onChange(value);
  }

  return /*#__PURE__*/_react["default"].createElement(_Page["default"], props, /*#__PURE__*/_react["default"].createElement(_Container["default"], null, /*#__PURE__*/_react["default"].createElement("div", {
    ref: mapRef,
    className: "map-container"
  }), /*#__PURE__*/_react["default"].createElement(_Control["default"].Location, {
    instance: instance,
    value: value,
    onChange: handleLocation
  })), /*#__PURE__*/_react["default"].createElement(_Footer["default"], {
    className: "map-footer"
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: "map-footer-content",
    onClick: handleReset
  }, /*#__PURE__*/_react["default"].createElement("p", {
    className: "map-footer-content-caption"
  }, (0, _locale["default"])('当前位置', 'current_location')), /*#__PURE__*/_react["default"].createElement("p", {
    className: "map-footer-content-sndcaption"
  }, ((_value = value) === null || _value === void 0 ? void 0 : _value.value) || '')), ((_value2 = value) === null || _value2 === void 0 ? void 0 : _value2.value) && /*#__PURE__*/_react["default"].createElement("span", {
    className: "map-footer-submit",
    onClick: handleSubmit
  }, (0, _locale["default"])('确定', 'ok'))), errMsg && /*#__PURE__*/_react["default"].createElement(_Notice["default"], {
    caption: errMsg
  }));
}

var _default = MapView;
exports["default"] = _default;
module.exports = exports.default;