"use strict";

exports.__esModule = true;
exports["default"] = void 0;

var _react = _interopRequireWildcard(require("react"));

var _instance = _interopRequireDefault(require("./instance.js"));

var _browser = _interopRequireDefault(require("./../Bridge/browser"));

var _locale = _interopRequireDefault(require("./../locale"));

var _excluded = ["src", "data", "params", "readOnly", "preview", "watermark", "onChange"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var loaded = 0; // eslint-disable-line

var Vott = (0, _react.forwardRef)(function (_ref, ref) {
  var src = _ref.src,
      _ref$data = _ref.data,
      data = _ref$data === void 0 ? [] : _ref$data,
      _ref$params = _ref.params,
      params = _ref$params === void 0 ? {} : _ref$params,
      _ref$readOnly = _ref.readOnly,
      readOnly = _ref$readOnly === void 0 ? true : _ref$readOnly,
      _ref$preview = _ref.preview,
      preview = _ref$preview === void 0 ? true : _ref$preview,
      watermark = _ref.watermark,
      onChange = _ref.onChange,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var rootRef = (0, _react.useRef)(null);
  var instance = (0, _react.useRef)(null);
  (0, _react.useImperativeHandle)(ref, function () {
    return {
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      },
      getInstance: function getInstance() {
        return instance.current;
      }
    };
  });
  (0, _react.useEffect)(function () {
    if (instance.current) instance.current.updateParams(params);
  }, [JSON.stringify(params)]);
  (0, _react.useEffect)(function () {
    if (instance.current) instance.current.setReadOnly(readOnly);
  }, [readOnly]);
  (0, _react.useEffect)(function () {
    if (instance.current) {
      instance.current.updateParams({
        src: src
      });
      loaded = 0;
      instance.current.update();
    }
  }, [src]);
  (0, _react.useEffect)(function () {
    if (instance.current) {
      instance.current.updateParams({
        data: data
      });
      loaded = 0;
      instance.current.update();
    }
  }, [data]);
  (0, _react.useEffect)(function () {
    instance.current = new _instance["default"](rootRef.current, _extends({
      readOnly: readOnly,
      data: data,
      src: src,
      onSuccess: load,
      onChange: handleChange
    }, params));
  }, []); // eslint-disable-line
  // 更新句柄, 防止synchronization模式, 每次组件在render的时候都生成上次render的state、function、effects

  if (instance.current) {
    instance.current.params.onChange = handleChange;
  }

  function handleChange(s, item, list) {
    if (rootRef.current) s.currentTarget = rootRef.current;
    if (onChange) onChange(s, item, list);
  }

  function load() {
    loaded = 1;
  }

  function click() {
    previewImage();
  }

  function previewImage() {
    if (!readOnly || !preview || !loaded) return; // 克隆Wrapper

    var wrapper = instance.current.wrapper;
    var previewHTML = "<div class=\"preview-layer\"> <div class=\"vott-wrapper\">" + wrapper.innerHTML + "</div></div>";

    _browser["default"].previewImage({
      urls: [src],
      layerHTML: previewHTML,
      success: function success(s) {
        var layer = s.container.querySelector('.preview-layer');
        wrapper = s.container.querySelector('.vott-wrapper');
        var svg = wrapper.querySelector('.vott-svg');
        svg.style.backgroundImage = 'initial'; // 计算宽高

        var width = svg.style.width.replace('px', '');
        var height = svg.style.height.replace('px', '');
        var scale = 1;

        if (width > height) {
          // 宽图计算
          scale = layer.clientWidth / width;
        } else {
          // 长图计算
          scale = layer.clientHeight / height;
        }

        wrapper.style.WebkitTransform = "scale(" + scale + ") translate(-50%,-50%)";
        wrapper.style.WebkitTransformOrigin = "0 0";
      }
    });
  }

  return /*#__PURE__*/_react["default"].createElement("div", _extends({
    ref: rootRef
  }, others, {
    className: "vott-container" + (others.className ? ' ' + others.className : '')
  }), /*#__PURE__*/_react["default"].createElement("div", {
    className: "vott-wrapper",
    onClick: click
  }, /*#__PURE__*/_react["default"].createElement("svg", {
    className: "vott-svg",
    preserveAspectRatio: "none"
  }), watermark && /*#__PURE__*/_react["default"].createElement("div", {
    className: "vott-watermark",
    style: {
      backgroundImage: "url(" + watermark + ")"
    }
  })), /*#__PURE__*/_react["default"].createElement("div", {
    className: "vott-loading active"
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: "vott-loading-icon"
  })), /*#__PURE__*/_react["default"].createElement("div", {
    className: "vott-error"
  }, /*#__PURE__*/_react["default"].createElement("div", {
    className: "vott-error-icon"
  }), /*#__PURE__*/_react["default"].createElement("div", {
    className: "vott-error-caption"
  }, (0, _locale["default"])('图片加载失败', 'hint_image_failed_to_load'))));
});
var _default = Vott;
exports["default"] = _default;
module.exports = exports.default;